"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.onSigint = void 0;
exports.poku = poku;
const node_process_1 = __importDefault(require("process"));
const write_js_1 = require("../../services/write.js");
const exit_js_1 = require("../helpers/exit.js");
const format_js_1 = require("../../services/format.js");
const files_js_1 = require("../../configs/files.js");
const run_tests_js_1 = require("../../services/run-tests.js");
const poku_js_1 = require("../../configs/poku.js");

const onSigint = () => node_process_1.default.stdout.write('\u001B[?25h');
exports.onSigint = onSigint;
node_process_1.default.once('SIGINT', exports.onSigint);
async function poku(targetPaths, configs) {
    let code = 0;
    if (configs)
        poku_js_1.GLOBAL.configs = { ...poku_js_1.GLOBAL.configs, ...configs };
    files_js_1.finalResults.started = new Date();
    const start = node_process_1.default.hrtime();
    const dirs = Array.prototype.concat(targetPaths);
    const showLogs = !poku_js_1.GLOBAL.configs.quiet;
    if (showLogs) {
        (0, write_js_1.hr)();
        (0, write_js_1.log)(`${(0, format_js_1.format)('Running Tests').bold()}\n`);
    }
    try {
        const promises = dirs.map(async (dir) => await (0, run_tests_js_1.runTests)(dir));
        const concurrency = await Promise.all(promises);
        if (concurrency.some((result) => !result))
            code = 1;
    }
    finally {
        const end = node_process_1.default.hrtime(start);
        const total = (end[0] * 1e3 + end[1] / 1e6).toFixed(6);
        files_js_1.finalResults.time = total;
    }
    showLogs && (0, format_js_1.showTestResults)();
    if (poku_js_1.GLOBAL.configs.noExit)
        return code;
    (0, exit_js_1.exit)(code, poku_js_1.GLOBAL.configs.quiet);
}
