"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.describe = void 0;
exports.describeBase = describeBase;
const node_process_1 = require("process");
const format_js_1 = require("../../services/format.js");
const write_js_1 = require("../../services/write.js");
const indentation_js_1 = require("../../configs/indentation.js");
const modifiers_js_1 = require("./modifiers.js");
const get_arg_js_1 = require("../../parsers/get-arg.js");
const callback_js_1 = require("../../parsers/callback.js");
const poku_js_1 = require("../../configs/poku.js");
async function describeBase(arg1, arg2) {
    let title;
    let cb;
    let options;
    if (typeof arg1 === 'string') {
        title = arg1;
        if (typeof arg2 === 'function')
            cb = arg2;
        else
            options = arg2;
    }
    else if (typeof arg1 === 'function') {
        cb = arg1;
        options = arg2;
    }
    if (title) {
        indentation_js_1.indentation.hasDescribe = true;
        const { background, icon } = options ?? Object.create(null);
        const message = `${cb ? (0, format_js_1.format)('◌').dim() : (icon ?? '☰')} ${cb ? (0, format_js_1.format)(title).dim() : (0, format_js_1.format)(title).bold()}`;
        const noBackground = !background;
        if (noBackground)
            (0, write_js_1.log)((0, format_js_1.format)(message).bold());
        else
            (0, write_js_1.log)((0, format_js_1.format)(` ${message} `).bg(typeof background === 'string' ? background : 'grey'));
    }
    if (typeof cb !== 'function')
        return;
    const start = (0, node_process_1.hrtime)();
    const resultCb = cb();
    if (resultCb instanceof Promise)
        await resultCb;
    const end = (0, node_process_1.hrtime)(start);
    if (!title)
        return;
    const total = (end[0] * 1e3 + end[1] / 1e6).toFixed(6);
    poku_js_1.GLOBAL.runAsOnly = false;
    indentation_js_1.indentation.hasDescribe = false;
    (0, write_js_1.log)(`${(0, format_js_1.format)(`● ${title}`).success().bold()} ${(0, format_js_1.format)(`› ${total}ms`).success().dim()}`);
}
async function describeCore(messageOrCb, cbOrOptions) {
    if (typeof messageOrCb === 'string' && typeof cbOrOptions !== 'function')
        return describeBase(messageOrCb, cbOrOptions);
    if (get_arg_js_1.hasOnly) {
        const hasItOnly = (0, callback_js_1.checkOnly)(typeof messageOrCb === 'function' ? messageOrCb : cbOrOptions);
        if (!hasItOnly)
            return;
        if (typeof messageOrCb === 'string' && typeof cbOrOptions === 'function')
            return describeBase(messageOrCb, cbOrOptions);
        if (typeof messageOrCb === 'function')
            return describeBase(messageOrCb);
    }
    if (typeof messageOrCb === 'string' && typeof cbOrOptions === 'function')
        return describeBase(messageOrCb, cbOrOptions);
    if (typeof messageOrCb === 'function')
        return describeBase(messageOrCb);
}
exports.describe = Object.assign(describeCore, {
    todo: modifiers_js_1.todo,
    skip: modifiers_js_1.skip,
    only: modifiers_js_1.onlyDescribe,
});
