"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.scriptRunner = exports.runner = exports.isWindows = void 0;
const node_process_1 = require("process");
const node_path_1 = require("path");
const get_runtime_js_1 = require("./get-runtime.js");
const poku_js_1 = require("../configs/poku.js");
exports.isWindows = node_process_1.platform === 'win32';
const runner = (filename) => {
    const runtime = (0, get_runtime_js_1.getRuntime)();
    if (runtime === 'bun')
        return ['bun'];
    if (runtime === 'deno') {
        const denoAllow = poku_js_1.GLOBAL.configs.deno?.allow
            ? poku_js_1.GLOBAL.configs.deno.allow
                .map((allow) => (allow ? `--allow-${allow}` : ''))
                .filter((allow) => allow)
            : ['--allow-read', '--allow-env', '--allow-run', '--allow-net'];
        const denoDeny = poku_js_1.GLOBAL.configs.deno?.deny
            ? poku_js_1.GLOBAL.configs.deno.deny
                .map((deny) => (deny ? `--deny-${deny}` : ''))
                .filter((deny) => deny)
            : [];
        return ['deno', 'run', ...denoAllow, ...denoDeny];
    }
    
    return ['.ts', '.mts', '.cts'].includes((0, node_path_1.extname)(filename))
        ? [exports.isWindows ? 'npx.cmd' : 'npx', 'tsx']
        : ['node'];
};
exports.runner = runner;
const scriptRunner = (runner) => {
    const commands = {
        npm: [exports.isWindows ? 'npm.cmd' : 'npm', 'run'],
        bun: ['bun', 'run'],
        deno: ['deno', 'task'],
        yarn: ['yarn'],
        pnpm: ['pnpm', 'run'],
    };
    return commands?.[runner] ?? commands['npm'];
};
exports.scriptRunner = scriptRunner;
