"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _a;
Object.defineProperty(exports, "__esModule", { value: true });
exports.processAsyncAssert = exports.processAssert = void 0;
const node_assert_1 = require("assert");
const node_process_1 = __importDefault(require("process"));
const node_path_1 = __importDefault(require("path"));
const find_file_from_stack_js_1 = require("../parsers/find-file-from-stack.js");
const assert_js_1 = require("../parsers/assert.js");
const indentation_js_1 = require("../configs/indentation.js");
const format_js_1 = require("./format.js");
const write_js_1 = require("./write.js");
const poku_js_1 = require("../configs/poku.js");
const { cwd } = poku_js_1.GLOBAL;
const regexFile = /file:(\/\/)?/;
const assertProcessor = () => {
    const { isPoku, FILE } = poku_js_1.GLOBAL;
    let preIdentation = '';
    const handleSuccess = (options) => {
        if (typeof options.message === 'string') {
            if (indentation_js_1.indentation.hasDescribe)
                preIdentation += '  ';
            if (indentation_js_1.indentation.hasItOrTest)
                preIdentation += '  ';
            const message = isPoku && !indentation_js_1.indentation.hasDescribe && !indentation_js_1.indentation.hasItOrTest
                ? `${preIdentation}${(0, format_js_1.format)(`${(0, format_js_1.format)(`✔ ${options.message}`).bold()} ${(0, format_js_1.format)(`› ${FILE}`).success().dim()}`).success()}`
                : `${preIdentation}${(0, format_js_1.format)(`✔ ${options.message}`).success().bold()}`;
            (0, write_js_1.log)(message);
        }
        preIdentation = '';
    };
    const handleError = (error, options) => {
        node_process_1.default.exitCode = 1;
        if (error instanceof node_assert_1.AssertionError) {
            const { code, actual, expected, operator } = error;
            const absolutePath = (0, find_file_from_stack_js_1.findFile)(error).replace(regexFile, '');
            const file = node_path_1.default.relative(node_path_1.default.resolve(cwd), absolutePath);
            if (indentation_js_1.indentation.hasDescribe)
                preIdentation += '  ';
            if (indentation_js_1.indentation.hasItOrTest)
                preIdentation += '  ';
            let message = '';
            if (typeof options.message === 'string')
                message = options.message;
            else if (options.message instanceof Error)
                message = options.message.message;
            else if (typeof options.defaultMessage === 'string')
                message = options.defaultMessage;
            const finalMessage = message?.trim().length > 0
                ? (0, format_js_1.format)(`✘ ${message}`).fail().bold()
                : (0, format_js_1.format)('✘ Assertion Error').fail().bold();
            (0, write_js_1.log)(isPoku
                ? `${preIdentation}${finalMessage} ${(0, format_js_1.format)(`› ${FILE}`).fail().dim()}`
                : `${preIdentation}${finalMessage}`);
            file && (0, write_js_1.log)(`${(0, format_js_1.format)(`${preIdentation}      File`).dim()} ${file}`);
            (0, write_js_1.log)(`${(0, format_js_1.format)(`${preIdentation}      Code`).dim()} ${code}`);
            (0, write_js_1.log)(`${(0, format_js_1.format)(`${preIdentation}  Operator`).dim()} ${operator}\n`);
            if (!options?.hideDiff) {
                const splitActual = (0, assert_js_1.parseResultType)(actual).split('\n');
                const splitExpected = (0, assert_js_1.parseResultType)(expected).split('\n');
                (0, write_js_1.log)((0, format_js_1.format)(`${preIdentation}  ${options?.actual ?? 'Actual'}:`).dim());
                for (const line of splitActual)
                    (0, write_js_1.log)(`${preIdentation}  ${(0, format_js_1.format)(line).fail().bold()}`);
                (0, write_js_1.log)(`\n${preIdentation}  ${(0, format_js_1.format)(`${options?.expected ?? 'Expected'}:`).dim()}`);
                for (const line of splitExpected)
                    (0, write_js_1.log)(`${preIdentation}  ${(0, format_js_1.format)(line).success().bold()}`);
                preIdentation = '';
            }
            if (options.throw) {
                console.error(error);
                (0, write_js_1.hr)();
            }
            if (isPoku)
                throw error;
        }
        
        throw error;
    };
    const processAssert = (cb, options) => {
        try {
            cb();
            handleSuccess(options);
        }
        catch (error) {
            handleError(error, options);
        }
    };
    const processAsyncAssert = async (cb, options) => {
        try {
            await cb();
            handleSuccess(options);
        }
        catch (error) {
            handleError(error, options);
        }
    };
    return { processAssert, processAsyncAssert };
};
_a = assertProcessor(), exports.processAssert = _a.processAssert, exports.processAsyncAssert = _a.processAsyncAssert;
