"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runTestFile = void 0;
const node_process_1 = require("process");
const node_path_1 = require("path");
const node_child_process_1 = require("child_process");
const files_js_1 = require("../configs/files.js");
const get_runner_js_1 = require("../parsers/get-runner.js");
const output_js_1 = require("../parsers/output.js");
const each_js_1 = require("./each.js");
const write_js_1 = require("./write.js");
const poku_js_1 = require("../configs/poku.js");
const { cwd } = poku_js_1.GLOBAL;
const runTestFile = async (filePath) => {
    const runtimeOptions = (0, get_runner_js_1.runner)(filePath);
    const runtime = runtimeOptions.shift();
    const runtimeArguments = [
        ...runtimeOptions,
        
        poku_js_1.GLOBAL.configs.deno?.cjs === true ||
            (Array.isArray(poku_js_1.GLOBAL.configs.deno?.cjs) &&
                poku_js_1.GLOBAL.configs.deno.cjs.some((ext) => filePath.includes(ext)))
            ? `https://cdn.jsdelivr.net/npm/poku${poku_js_1.VERSION ? `@${poku_js_1.VERSION}` : ''}/lib/polyfills/deno.mjs`
            : filePath,
    ];
    const fileRelative = (0, node_path_1.relative)(cwd, filePath);
    const showLogs = !poku_js_1.GLOBAL.configs.quiet;
    let output = '';
    const stdOut = (data) => {
        output += String(data);
    };
    const start = (0, node_process_1.hrtime)();
    let end;
    if (!(await (0, each_js_1.beforeEach)(fileRelative)))
        return false;
    return new Promise((resolve) => {
        const child = (0, node_child_process_1.spawn)(runtime, [...runtimeArguments, ...poku_js_1.deepOptions], {
            stdio: ['inherit', 'pipe', 'pipe'],
            shell: get_runner_js_1.isWindows,
            env: {
                ...node_process_1.env,
                POKU_FILE: fileRelative,
                POKU_RUNTIME: node_process_1.env.POKU_RUNTIME,
            },
        });
        child.stdout.setEncoding('utf8');
        child.stderr.setEncoding('utf8');
        child.stdout.on('data', stdOut);
        child.stderr.on('data', stdOut);
        child.on('close', async (code) => {
            end = (0, node_process_1.hrtime)(start);
            const result = code === 0;
            if (showLogs) {
                const mappedOutputs = (0, output_js_1.parserOutput)({
                    output,
                    result,
                });
                mappedOutputs && (0, write_js_1.log)(mappedOutputs.join('\n'));
            }
            if (!(await (0, each_js_1.afterEach)(fileRelative))) {
                resolve(false);
                return;
            }
            const total = (end[0] * 1e3 + end[1] / 1e6).toFixed(6);
            if (result)
                files_js_1.fileResults.success.set(fileRelative, total);
            else
                files_js_1.fileResults.fail.set(fileRelative, total);
            resolve(result);
        });
        
        child.on('error', (err) => {
            end = (0, node_process_1.hrtime)(start);
            const total = (end[0] * 1e3 + end[1] / 1e6).toFixed(6);
            console.error(`Failed to start test: ${filePath}`, err);
            files_js_1.fileResults.fail.set(fileRelative, total);
            resolve(false);
        });
    });
};
exports.runTestFile = runTestFile;
