"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runTests = void 0;
const node_process_1 = __importDefault(require("process"));
const node_path_1 = require("path");
const list_files_js_1 = require("../modules/helpers/list-files.js");
const write_js_1 = require("../services/write.js");
const format_js_1 = require("./format.js");
const run_test_file_js_1 = require("./run-test-file.js");
const poku_js_1 = require("../configs/poku.js");
const os_js_1 = require("../polyfills/os.js");
const get_arg_js_1 = require("../parsers/get-arg.js");
const { cwd } = poku_js_1.GLOBAL;
const failFastError = `  ${(0, format_js_1.format)('ℹ').fail()} ${(0, format_js_1.format)('failFast').bold()} is enabled`;
if (get_arg_js_1.hasOnly)
    poku_js_1.deepOptions.push('--only');
const runTests = async (dir) => {
    let allPassed = true;
    let activeTests = 0;
    let resolveDone;
    let rejectDone;
    const testDir = (0, node_path_1.join)(cwd, dir);
    const files = await (0, list_files_js_1.listFiles)(testDir, poku_js_1.GLOBAL.configs);
    const showLogs = !poku_js_1.GLOBAL.configs.quiet;
    const concurrency = (() => {
        if (poku_js_1.GLOBAL.configs.sequential)
            return 1;
        const limit = poku_js_1.GLOBAL.configs.concurrency ?? Math.max((0, os_js_1.availableParallelism)() - 1, 1);
        return limit <= 0 ? files.length || 1 : limit;
    })();
    const done = new Promise((resolve, reject) => {
        resolveDone = resolve;
        rejectDone = reject;
    });
    const runNext = async () => {
        if (files.length === 0 && activeTests === 0) {
            resolveDone(allPassed);
            return;
        }
        const filePath = files.shift();
        if (typeof filePath === 'undefined')
            return;
        activeTests++;
        try {
            const testPassed = await (0, run_test_file_js_1.runTestFile)(filePath);
            if (testPassed)
                ++poku_js_1.results.success;
            else {
                ++poku_js_1.results.fail;
                allPassed = false;
                if (poku_js_1.GLOBAL.configs.failFast) {
                    if (showLogs) {
                        (0, write_js_1.hr)();
                        console.error(failFastError);
                        (0, write_js_1.log)(`\n    ${(0, format_js_1.format)('File:').bold()} ${(0, format_js_1.format)(`./${(0, node_path_1.relative)(cwd, filePath)}`).fail()}`);
                        (0, write_js_1.hr)();
                    }
                    node_process_1.default.exit(1);
                }
            }
        }
        finally {
            activeTests--;
        }
        runNext().catch(rejectDone);
    };
    for (let i = 0; i < concurrency; i++)
        runNext();
    return await done;
};
exports.runTests = runTests;
